<p align="center">
<a href="#">
<img src="https://cdn.nlark.com/yuque/0/2022/png/153412/1643364757640-b4529458-ec8d-42cc-a2d8-c0ce60fdf50f.png" alt="SoloX" width="300">
</a>
<br>
<br>
</p>
<p align="center">
<a href="https://pypi.org/project/solox/" target="__blank"><img src="https://img.shields.io/static/v1?label=Download&message=1.0.11&color=228be6" alt="SmartTest preview"></a>
<br>
</p>

## SoloX

SoloX - APP性能数据实时收集工具。

我们致力于解决低效、繁琐的测试执行，我们的目标是Simple Test In SoloX !


## 功能
#### 首页
<img src="https://cdn.nlark.com/yuque/0/2022/png/153412/1646636392193-c16d5102-9dc3-49d3-a3fe-eede97c6f2aa.png?x-oss-process=image%2Fresize%2Cw_1500%2Climit_0"  width="100%">

#### 报告
<img src="https://cdn.nlark.com/yuque/0/2022/png/153412/1646636399507-513b79ce-e21d-42ae-a17b-1c5bb6fefed2.png?x-oss-process=image%2Fresize%2Cw_1500%2Climit_0"  width="100%">

#### 分析
<img src="https://cdn.nlark.com/yuque/0/2022/png/153412/1646636405058-5293c9fa-fa52-471b-8e44-69cf3c60e12c.png?x-oss-process=image%2Fresize%2Cw_1500%2Climit_0"  width="100%">

## 安装
```
1.Python:3.6+ 
2.pip3 install -U solox
```

## 启动
```
执行：python3 -m solox

 * Serving Flask app 'run' (lazy loading)
 * Environment: production
   WARNING: This is a development server. Do not use it in a production deployment.
   Use a production WSGI server instead.
 * Debug mode: on
 * Running on all addresses.
   WARNING: This is a development server. Do not use it in a production deployment.
 * Running on http://xx.xx.xx.xx:5000/ (Press CTRL+C to quit)
 * Restarting with stat
 * Debugger is active!
 * Debugger PIN: 906-499-328

```
